local scream = Resources.load_audio("falzar.ogg")

function card_init(player)
  local action = Action.new(player, "CHARACTER_HIT")
  action:set_lockout(ActionLockout.new_sequence())
  action.on_execute_func = function(self, user)
    local step = self:create_step()
    local tremor_component = user:create_component(Lifetime.ActiveBattle)
    local field = user:field()
    -- c is a character. check the team. if not the same, return true.
    -- also ensure they aren't using AirShoes to avoid holes etc
    local query = function(c) return c:team() ~= user:team() and not c:is_moving() and not c:ignoring_hole_tiles() end
    local targets = field:find_characters(query) --acquire a list of all characters meeting the above condition.
    tremor_component.targets = targets
    tremor_component.field = field
    tremor_component.index = 1
    tremor_component.on_update_func = function(self)
      local owner = self:owner()
      if self.index > #self.targets then
        self:eject()
        return
      end
      local foe = self.targets[self.index]
      local hitbox = Spell.new(owner:team())
      hitbox:set_hit_props(
        HitProps.new(
          0,               --Damage
          Hit.Root,        --Hit Flags. Use without Impact to hit through defenses.
          Element.None,    --Element
          owner:context(), --Context, set to nil so as not to counter in build 2.0
          Drag.None        --Drag direction
        )
      )
      hitbox.cooldown = 3
      hitbox.on_update_func = function(self)
        local tile = self:current_tile()
        --Only root if tile is walkable.
        if tile:is_walkable() then tile:attack_entities(self) end
        self.cooldown = self.cooldown - 1
        --Nesting bullshit. Reads as "if cooldown is less than 0, and if I'm not deleted, then erase myself."
        if self.cooldown <= 0 then if not self:deleted() then self:erase() end end
      end

      self.field:spawn(hitbox, foe:current_tile())
      self.index = self.index + 1
    end

    step.on_update_func = function(self)
      user:field():shake(5.0, 60)
      Resources.play_audio(scream, AudioBehavior.NoOverlap)
      self:complete_step()
    end
  end
  return action
end
